HS_empirical_bootstrap_test: Empirical bootstrap test for
separability of covariance structure using Hilbert--Schmidt distance
Description
Empirical bootstrap test for
separability of covariance structure using Hilbert--Schmidt distance
Usage
HS_empirical_bootstrap_test(Data, B = 100, verbose = TRUE)
Arguments
Data
a (non-empty) N x d1 x d2 array of data values. The first
direction indices the \(N\) observations, each consisting of a d1 x d2
discretization of the surface, so that Data[i,,] corresponds to the
i-th observed surface.
B
number of bootstrap replicates to be used.
verbose
logical parameter for printing progress
Value
The p-value of the test.
Details
This function performs the test of separability
of the covariance structure for a random surface (introduced in the paper
http://arxiv.org/abs/1505.02023), when generated from a Gaussian
process. The sample surfaces need to be measured on a common regular grid. The test
considers the Hilbert--Schmidt distance between the sample covariance and its
separable approximation. WE DO NOT RECOMMEND THIS TEST, as it is does not have the
correct level, nor good power.
# NOT RUN {data(SurfacesData)
# }# NOT RUN {HS_empirical_bootstrap_test(SurfacesData)
# }# NOT RUN {HS_empirical_bootstrap_test(SurfacesData, B = 100)
# }