SurfacesData: A data set of surfaces

SurfacesDataR Documentation

A data set of surfaces

Description

Dataset of 50 surfaces simulated from a Gaussian process with a separable covariance structure. SurfacesData[i,,] corresponds to the i-th surface observed on a 32x7 uniform grid.

Usage

SurfacesData

Format

An object of class array of dimension 50 x 32 x 7.

Details

This is a 50 x 32 x 7 array.

Examples

data(SurfacesData)
image(SurfacesData[1,,]) # color image of the first surface in the dataset

covsep documentation built on June 26, 2026, 5:08 p.m.

Related to SurfacesData in covsep...