covsep: covsep: tests for determining if the covariance structure of...

covsepR Documentation

covsep: tests for determining if the covariance structure of 2-dimensional data is separable

Description

Functions for testing if the covariance structure of 2-dimensional data (e.g. samples of surfaces X_i = X_i(s,t)) is separable, i.e. if cov(X) = C_1 x C_2. A complete descriptions of the implemented tests can be found in the paper Aston et al. (2017); see references below.

Main functions

The main functions are

  • clt_test,

  • gaussian_bootstrap_test,

  • empirical_bootstrap_test,

  • HS_gaussian_bootstrap_test,

  • HS_empirical_bootstrap_test

Author(s)

Maintainer: Shahin Tavakoli shahin.tavakoli@unige.ch (ORCID)

Authors:

Other contributors:

References

Aston, John A. D.; Pigoli, Davide; Tavakoli, Shahin. Tests for separability in nonparametric covariance operators of random surfaces. Ann. Statist. 45 (2017), no. 4, 1431–1461. <doi:10.1214/16-AOS1495>. <https://projecteuclid.org/euclid.aos/1498636862>

See Also

Useful links:

  • \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/16-AOS1495")}

covsep documentation built on June 26, 2026, 5:08 p.m.

Related to covsep in covsep...