This function performs the test for the separability of covariance structure of a random surface generated from a Gaussian process, based on the parametric bootstrap procedure described in the paper http://arxiv.org/abs/1505.02023
gaussian_bootstrap_test(Data, L1 = 1, L2 = 2, studentize = "full",
B = 1000, verbose = TRUE)a (non-empty) N x d1 x d2 array of data values. The first
direction indices the \(N\) observations, each consisting of a d1 x d2
discretization of the surface, so that Data[i,,] corresponds to the
i-th observed surface.
an integer or vector of integers in \(1:p\) indicating the eigenfunctions in the first direction to be used for the test.
an integer or vector of integers in \(1:q\) indicating the eigenfunctions in the second direction to be used for the test.
parameter to specify which type of studentization is performed. Possible options are 'no', 'diag' or 'full' (see details section).
number of bootstrap replicates to be used.
logical parameter for printing progress
The p-value of the test for each pair (l1,l2) = (L1[k], L2[k]), for k = 1:length(L1).
This function performs the test of separability of the covariance structure for a random surface (introduced in the paper http://arxiv.org/abs/1505.02023), when generated from a Gaussian process. The sample surfaces need to be measured on a common regular grid. The test consider a subspace formed by the tensor product of eigenfunctions of the separable covariances. It is possible to specify the number of eigenfunctions to be considered in each direction.
If L1 and L2 are vectors, they need to be of the same length.
The function tests for separability using the projection of the covariance
operator in the separable eigenfunctions u_i x v_j : i = 1, …, l1;
j = 1, …, l2, for each pair (l1,l2) = (L1[k], L2[k]), for k = 1:length(L1).
studentize can take the values
default & recommended method. Yhe projection coordinates are renormalized by an estimate of their joint covariance
NOT RECOMMENDED. No studentization is performed
NOT RECOMMENDED. Each projection coordinate is renormalized by an estimate of its standard deviation
B the number of bootstrap replicates (1000 by default).
verbose to print the progress of the computations (TRUE by default)
Aston, John A. D.; Pigoli, Davide; Tavakoli, Shahin. Tests for separability in nonparametric covariance operators of random surfaces. Ann. Statist. 45 (2017), no. 4, 1431--1461. doi:10.1214/16-AOS1495. https://projecteuclid.org/euclid.aos/1498636862
# NOT RUN {
data(SurfacesData)
# }
# NOT RUN {
gaussian_bootstrap_test(SurfacesData)
# }
# NOT RUN {
gaussian_bootstrap_test(SurfacesData, B=100)
# }
# NOT RUN {
gaussian_bootstrap_test(SurfacesData, L1=2,L2=2,B=1000, studentize='full')
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab