| renormalize_mtnorm | R Documentation |
renormalize a matrix normal random matrix to have iid entries
renormalize_mtnorm(X, C1, C2, type = "full")
X |
a matrix normal random matrix with mean zero |
C1 |
row covariance |
C2 |
column covariance |
type |
the type of renormalization to do. Possible options are 'no', 'diag' or 'full' (see details section). |
A matrix with renormalized entries
type can take the values
each entry of X is renormalized by its marginal standard deviation
X is renormalized by its root inverse covariance
Data <- rmtnorm(30, C1, C2)
ans <- renormalize_mtnorm(Data[1,,], C1, C2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.