| SurfacesData | R Documentation |
Dataset of 50 surfaces simulated from a Gaussian process with a separable covariance structure. SurfacesData[i,,] corresponds to the i-th surface observed on a 32x7 uniform grid.
SurfacesData
An object of class array of dimension 50 x 32 x 7.
This is a 50 x 32 x 7 array.
data(SurfacesData)
image(SurfacesData[1,,]) # color image of the first surface in the dataset
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.