| covsep | R Documentation |
Functions for testing if the covariance structure of 2-dimensional data (e.g. samples of surfaces X_i = X_i(s,t)) is separable, i.e. if cov(X) = C_1 x C_2. A complete descriptions of the implemented tests can be found in the paper Aston et al. (2017); see references below.
The main functions are
clt_test,
gaussian_bootstrap_test,
empirical_bootstrap_test,
HS_gaussian_bootstrap_test,
HS_empirical_bootstrap_test
Maintainer: Shahin Tavakoli shahin.tavakoli@unige.ch (ORCID)
Authors:
Shahin Tavakoli shahin.tavakoli@unige.ch (ORCID)
Other contributors:
Davide Pigoli davide.pigoli@kcl.ac.uk [contributor]
John Aston j.aston@statslab.cam.ac.uk [contributor]
Aston, John A. D.; Pigoli, Davide; Tavakoli, Shahin. Tests for separability in nonparametric covariance operators of random surfaces. Ann. Statist. 45 (2017), no. 4, 1431–1461. <doi:10.1214/16-AOS1495>. <https://projecteuclid.org/euclid.aos/1498636862>
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.