powered by
renormalize a matrix normal random matrix to have iid entries
renormalize_mtnorm(X, C1, C2, type = "full")
a matrix normal random matrix with mean zero
row covariance
column covariance
the type of renormalization to do. Possible options are 'no', 'diag' or 'full' (see details section).
A matrix with renormalized entries
type can take the values
type
each entry of X is renormalized by its marginal standard deviation
X
X is renormalized by its root inverse covariance
# NOT RUN { Data <- rmtnorm(30, C1, C2) ans <- renormalize_mtnorm(Data[1,,], C1, C2) # }
Run the code above in your browser using DataLab